equal1: Non-symmetric version of EQUAL

View source: R/RcppExports.R

equal1R Documentation

Non-symmetric version of EQUAL

Description

ADMM algorithm for high precision matrix estimation using asymmetic loss

Usage

equal1(X, lambda, err = 10^(-5), maxIter = 1000L, rho = 1, diag = 0L)

Arguments

X

data matrix of dimension n*p.

lambda

user supplied tuning parameter;

err

the precision used to stop the convergence. Default is 1e-5. Iterations stop when average absolute parameter change is less than err.

maxIter

Maximum number of iterations. Default is 1000.

rho

step parameter for the ADMM. Default is 1.

diag

Should diagonal elements of the Matrix be thresholding? Default is FALSE.

Value

A list with components

Omega

a list of sparse p*p matrices corresponding to lambda.

lambda

the used lambda for the solution path.

niter

the number of iterations for each element of lambda.


cescwang85/EQUAL documentation built on Nov. 26, 2022, 1:27 a.m.