refit_list: Estimate the precision matrix with the given support from a...

View source: R/refit_list.R

refit_listR Documentation

Estimate the precision matrix with the given support from a list of sparse matrix

Description

Estimate the precision matrix with the given support from a list of sparse matrix

Usage

refit_list(X, obj, rho = 1, err = 0.001)

Arguments

X

data matrix of dimension n\times p.

obj

a list of sparse p \times p matrices whose support is used to estimate the precision matrix.

rho

step parameter for the ADMM. Default is 1.

err

the precision used to stop the convergence. Default is 1e-3.

Value

A list of p \times p precision matrices whose support is consistent with the one of obj.


cescwang85/EQUAL documentation built on Nov. 26, 2022, 1:27 a.m.