refit_mat: Estimate the precision matrix with the given support

View source: R/refit_mat.R

refit_matR Documentation

Estimate the precision matrix with the given support

Description

Estimate the precision matrix with the given support

Usage

refit_mat(X, obj, rho = 1, err = 0.001)

Arguments

X

data matrix of dimension n\times p.

obj

a p \times p matrix whose support is used to estimate the precision matrix.

rho

step parameter for the ADMM. Default is 1.

err

the precision used to stop the convergence. Default is 1e-3.

Value

A p \times p precision matrix whose support is consistent with the one of obj.


cescwang85/EQUAL documentation built on Nov. 26, 2022, 1:27 a.m.