| EQUAL | R Documentation |
Efficient admm algorithm via the QUAdratic Loss (EQUAL) for precision matrix estimation
EQUAL( X, type = TRUE, sdiag = FALSE, lambda = NULL, lambda.min = sqrt(log(ncol(X))/nrow(X)), nlambda = 50, err = 10^(-5), maxIter = 1000, rho = 1 )
X |
data matrix of dimension n*p. |
type |
Should the loss function be symmetric? Default is TRUE. |
sdiag |
Should diagonal of inverse covariance be penalized? Default is FALSE. |
lambda |
user supplied tuning parameter; Default is NULL and the program compute its own
sequence based on |
lambda.min |
smallest value for lambda, as a fraction of lambda.max which is available when lambda is NULL. Default is sqrt(log(p)/n). |
nlambda |
the length of the tuning parameter sequence which is available when lambda is NULL. Default is 50. |
err |
the precision used to stop the convergence. Default is 1e-5.
Iterations stop when average absolute parameter change is less than |
maxIter |
Maximum number of iterations. Default is 1000. |
rho |
step parameter for the ADMM. Default is 1. |
A list with components
Omega |
a list of sparse p*p matrices corresponding to lambda. |
lambda |
the used lambda for the solution path. |
niter |
the number of iterations for each element of lambda. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.