| equal2 | R Documentation |
ADMM algorithm for high precision matrix estimation using symmetic loss
equal2(X, lambda, err = 10^(-5), maxIter = 1000L, rho = 1, diag = 0L)
X |
data matrix of dimension n*p. |
lambda |
user supplied tuning parameter; |
err |
the precision used to stop the convergence. Default is 1e-5.
Iterations stop when average absolute parameter change is less than |
maxIter |
Maximum number of iterations. Default is 1000. |
rho |
step parameter for the ADMM. Default is 1. |
diag |
Should diagonal elements of the Matrix be thresholding? Default is FALSE. |
A list with components
Omega |
a list of sparse p*p matrices corresponding to lambda. |
lambda |
the used lambda for the solution path. |
niter |
the number of iterations for each element of lambda. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.