| refit_list | R Documentation |
Estimate the precision matrix with the given support from a list of sparse matrix
refit_list(X, obj, rho = 1, err = 0.001)
|
data matrix of dimension n\times p. |
|
a list of sparse p \times p matrices whose support is used to estimate the precision matrix. |
|
step parameter for the ADMM. Default is 1. |
|
the precision used to stop the convergence. Default is 1e-3. |
A list of p \times p precision matrices whose support is consistent with the one of obj.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.