| refit_mat | R Documentation |
Estimate the precision matrix with the given support
refit_mat(X, obj, rho = 1, err = 0.001)
|
data matrix of dimension n\times p. |
|
a p \times p matrix whose support is used to estimate the precision matrix. |
|
step parameter for the ADMM. Default is 1. |
|
the precision used to stop the convergence. Default is 1e-3. |
A p \times p precision matrix whose support is consistent with the one of obj.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.